==> imio.smartweb.core-1.2.29-py3-none-any.whl: imio/smartweb/core/webcomponents/src/utils/translation.js <==
export default {
    // common
    'Chargement...': {
        en: 'Loading',
        fr: 'Chargement...',
        de: 'Laden',
        nl: 'Laden...',
    },
    "Recherche": {
        en: 'Search',
        fr: "Recherche",
        de: "Suche",
        nl: "Zoeken",
    },
    "Thématiques": {
        en: 'Themes',
        fr: "Thématiques",
        de: "Themen",
        nl: "Thema's",
    },
    "Catégories": {
        en: 'Categories',
        fr: "Catégories",
        de: "Kategorien",
        nl: "Categorieën",
    },
    "Facilités": {
        en: 'Facilities',
        fr: "Facilités",
        de: "Einrichtungen",
        nl: "Faciliteiten",
    },
    'Plus de résultats': {
        en: 'More results',
        fr: 'Plus de résultats',
        de: 'Mehr Ergebnisse',
        nl: 'Meer resultaten',
    },
    'Aucun résultat': {
        en: 'No result',
        fr: 'Aucun résultat',
        de: 'Kein Ergebnis',
        nl: 'Geen resultaat',
    },
    'Retour': {
        en: 'Return',
        fr: 'Retour',
        de: 'Zurück',
        nl: 'Terug',
    },
    'Téléchargements': {
        en: 'Downloads',
        fr: 'Téléchargements',
        de: 'Downloads',
        nl: 'Downloads',
    },
    'Billetterie': {
        en: 'Ticketing',
        fr: 'Billetterie',
        de: 'Tickets',
        nl: 'Ticketverkoop',
    },
    'Lien vers la vidéo': {
        en: 'Link to video',
        fr: 'Lien vers la vidéo',
        de: 'Link zum Video',
        nl: 'Link naar video',
    },
    'Participation en ligne': {
        en: 'Join online',
        fr: 'Participation en ligne',
        de: 'Online teilnehmen',
        nl: 'Doe online mee',
    },
    'Actualités trouvées': {
        en: ' News found',
        fr: ' Actualités trouvées',
        de: ' Nachrichten gefunden',
        nl: ' Nieuws gevonden',
    },
    'Actualité trouvée': {
        en: ' News found',
        fr: ' Atualité trouvée',
        de: ' Nachricht gefunden',
        nl: ' Nieuws gevonden',
    },
    "Aucune actualité n'a été trouvée": {
        en: 'No news was found',
        fr: "Aucune actualité n'a été trouvée",
        de: 'Keine Nachrichten gefunden',
        nl: 'Geen nieuws gevonden',
    },
    "Proposer une actualité": {
        en: 'Suggest a news',
        fr: "Proposer une actualité",
        de: 'Nachricht vorschlagen',
        nl: 'Nieuws voorstellen',
    },
    'événements trouvés': {
        en: ' Events found',
        fr: ' Événements trouvés',
        de: ' Veranstaltungen gefunden',
        nl: ' Evenementen gevonden',
    },
    'événement trouvé': {
        en: ' Event found',
        fr: ' Événement trouvé',
        de: ' Veranstaltung gefunden',
        nl: ' Evenement gevonden',
    },
    "Aucun événement n'a été trouvé": {
        en: 'No event was found',
        fr: "Aucun événement n'a été trouvé",
        de: 'Keine Veranstaltungen gefunden',
        nl: 'Geen evenement gevonden',
    },
    "Proposer un événement": {
        en: 'Suggest a event',
        fr: "Proposer un événement",
        de: 'Veranstaltung vorschlagen',
        nl: 'Evenement voorstellen',
    },
    "Infos pratiques": {
        en: 'Practical information',
        fr: "Infos pratiques",
        de: 'Praktische Informationen',
        nl: 'Praktische informatie',
    },
    "Accessible aux PMR": {
        en: 'Accessibility for PRM',
        fr: "Accessible aux PMR",
        de: 'Barrierefreiheit für PMR',
        nl: 'Toegankelijk voor PRM',
    },
    "Lien de l'événement": {
        en: 'Event link',
        fr: "Lien de l'événement",
        de: 'Veranstaltungslink',
        nl: 'Evenement link',
    },
    'contacts trouvés': {
        en: ' Contact found',
        fr: ' Contacts trouvés',
        de: ' Kontakt gefunden',
        nl: ' Contact gevonden',
    },
    'contact trouvé': {
        en: ' Contact found',
        fr: ' Contact trouvé',
        de: ' Kontakt gefunden',
        nl: ' Contact gevonden',
    },
    "Aucun contact n'a été trouvé": {
        en: 'No contact was found',
        fr: "Aucun contact n'a été trouvé",
        de: 'Kein Kontakt gefunden',
        nl: 'Geen contact gevonden',
    },
    "Proposer un contact": {
        en: 'Suggest a contact',
        fr: "Proposer un contact",
        de: 'Kontakt vorschlagen',
        nl: 'Contact voorstellen',
    },
    "Toutes les dates": {
        en: 'All dates',
        fr: "Toutes les dates",
        de: 'Alle Daten',
        nl: 'Alle data',
    },
    "Aujourd'hui": {
        en: "Today",
        fr: "Aujourd'hui",
        de: "Heute",
        nl: "Vandaag",
    },
    "Demain": {
        en: "Tomorrow",
        fr: "Demain",
        de: "Morgen",
        nl: "Morgen",
    }, 
    "Ce week-end": {
        en: "This weekend",
        fr: "Ce week-end",
        de: "Dieses Wochenende",
        nl: "Dit weekend",
    }, 
    "Cette semaine": {
        en: "This week",
        fr: "Cette semaine",
        de: "Diese Woche",
        nl: "Deze week",
    },
    "Ce mois-ci": {
        en: "This month",
        fr: "Ce mois-ci",
        de: "Diesen Monat",
        nl: "Deze maand",
    },  
    "Personnalisé (Du ... au ...)": {
        en: "Custom (From ... to ...)",
        fr: "Personnalisé (Du ... au ...)",
        de: "Benutzerdefiniert (Von ... bis ...)",
        nl: "Aangepast (Van ... tot ...)",
    },
    "Personnalisé": {
        en: "Custom",
        fr: "Personnalisé",
        de: "Benutzerdefiniert",
        nl: "Aangepast",
    }
}

==> imio.smartweb.core-1.2.32-py3-none-any.whl: imio/smartweb/core/webcomponents/src/utils/translation.js <==
export default {
    // common
    'Publié' : {
        en: 'Published',
        fr: 'Publié',
        de: 'Veröffentlicht',
        nl: 'Gepubliceerd',
    },
    'Actualisé' : {
        en: 'Updated',
        fr: 'Actualisé',
        de: 'Aktualisiert',
        nl: 'Bijgewerkt',
    },
    'Événements' : {
        en: 'Events',
        fr: 'Événements',
        de: 'Veranstaltungen',
        nl: 'Evenementen',
    },
    'Actualités' : {
        en: 'News',
        fr: 'Actualités',
        de: 'Nachrichten',
        nl: 'Nieuws',
    },
    'Contacts': {
        en: 'Contacts',
        fr: 'Contacts',
        de: 'Kontakte',
        nl: 'Contacten',
    },
    'Infos pratiques': {
        en: 'Practical information',
        fr: 'Infos pratiques',
        de: 'Praktische Informationen',
        nl: 'Praktische informatie',
    },
    'Chargement...': {
        en: 'Loading',
        fr: 'Chargement...',
        de: 'Laden',
        nl: 'Laden...',
    },
    "Recherche": {
        en: 'Search',
        fr: "Recherche",
        de: "Suche",
        nl: "Zoeken",
    },
    "Thématiques": {
        en: 'Themes',
        fr: "Thématiques",
        de: "Themen",
        nl: "Thema's",
    },
    'Je suis': {
        en: 'I am',
        fr: 'Je suis',
        de: 'Ich bin',
        nl: 'Ik ben',
    },
    "Catégories": {
        en: 'Categories',
        fr: "Catégories",
        de: "Kategorien",
        nl: "Categorieën",
    },
    "Facilités": {
        en: 'Facilities',
        fr: "Facilités",
        de: "Einrichtungen",
        nl: "Faciliteiten",
    },
    'Plus de résultats': {
        en: 'More results',
        fr: 'Plus de résultats',
        de: 'Mehr Ergebnisse',
        nl: 'Meer resultaten',
    },
    'Aucun résultat': {
        en: 'No result',
        fr: 'Aucun résultat',
        de: 'Kein Ergebnis',
        nl: 'Geen resultaat',
    },
    'Résultats': {
        en: 'Results',
        fr: 'Résultats',
        de: 'Ergebnisse',
        nl: 'Resultaten',
    },
    'Retour': {
        en: 'Return',
        fr: 'Retour',
        de: 'Zurück',
        nl: 'Terug',
    },
    'Téléchargements': {
        en: 'Downloads',
        fr: 'Téléchargements',
        de: 'Downloads',
        nl: 'Downloads',
    },
    'Billetterie': {
        en: 'Ticketing',
        fr: 'Billetterie',
        de: 'Tickets',
        nl: 'Ticketverkoop',
    },
    'Lien vers la vidéo': {
        en: 'Link to video',
        fr: 'Lien vers la vidéo',
        de: 'Link zum Video',
        nl: 'Link naar video',
    },
    'Participation en ligne': {
        en: 'Join online',
        fr: 'Participation en ligne',
        de: 'Online teilnehmen',
        nl: 'Doe online mee',
    },
    'Actualités trouvées': {
        en: ' News found',
        fr: ' Actualités trouvées',
        de: ' Nachrichten gefunden',
        nl: ' Nieuws gevonden',
    },
    'Actualité trouvée': {
        en: ' News found',
        fr: ' Atualité trouvée',
        de: ' Nachricht gefunden',
        nl: ' Nieuws gevonden',
    },
    "Aucune actualité n'a été trouvée": {
        en: 'No news was found',
        fr: "Aucune actualité n'a été trouvée",
        de: 'Keine Nachrichten gefunden',
        nl: 'Geen nieuws gevonden',
    },
    "Proposer une actualité": {
        en: 'Suggest a news',
        fr: "Proposer une actualité",
        de: 'Nachricht vorschlagen',
        nl: 'Nieuws voorstellen',
    },
    'événements trouvés': {
        en: ' Events found',
        fr: ' Événements trouvés',
        de: ' Veranstaltungen gefunden',
        nl: ' Evenementen gevonden',
    },
    'événement trouvé': {
        en: ' Event found',
        fr: ' Événement trouvé',
        de: ' Veranstaltung gefunden',
        nl: ' Evenement gevonden',
    },
    "Aucun événement n'a été trouvé": {
        en: 'No event was found',
        fr: "Aucun événement n'a été trouvé",
        de: 'Keine Veranstaltungen gefunden',
        nl: 'Geen evenement gevonden',
    },
    "Proposer un événement": {
        en: 'Suggest a event',
        fr: "Proposer un événement",
        de: 'Veranstaltung vorschlagen',
        nl: 'Evenement voorstellen',
    },
    "Infos pratiques": {
        en: 'Practical information',
        fr: "Infos pratiques",
        de: 'Praktische Informationen',
        nl: 'Praktische informatie',
    },
    "Accessible aux PMR": {
        en: 'Accessibility for PRM',
        fr: "Accessible aux PMR",
        de: 'Barrierefreiheit für PMR',
        nl: 'Toegankelijk voor PRM',
    },
    "Lien de l'événement": {
        en: 'Event link',
        fr: "Lien de l'événement",
        de: 'Veranstaltungslink',
        nl: 'Evenement link',
    },
    'contacts trouvés': {
        en: ' Contact found',
        fr: ' Contacts trouvés',
        de: ' Kontakt gefunden',
        nl: ' Contact gevonden',
    },
    'contact trouvé': {
        en: ' Contact found',
        fr: ' Contact trouvé',
        de: ' Kontakt gefunden',
        nl: ' Contact gevonden',
    },
    "Aucun contact n'a été trouvé": {
        en: 'No contact was found',
        fr: "Aucun contact n'a été trouvé",
        de: 'Kein Kontakt gefunden',
        nl: 'Geen contact gevonden',
    },
    "Proposer un contact": {
        en: 'Suggest a contact',
        fr: "Proposer un contact",
        de: 'Kontakt vorschlagen',
        nl: 'Contact voorstellen',
    },
    "Toutes les dates": {
        en: 'All dates',
        fr: "Toutes les dates",
        de: 'Alle Daten',
        nl: 'Alle data',
    },
    "Aujourd'hui": {
        en: "Today",
        fr: "Aujourd'hui",
        de: "Heute",
        nl: "Vandaag",
    },
    "Demain": {
        en: "Tomorrow",
        fr: "Demain",
        de: "Morgen",
        nl: "Morgen",
    }, 
    "Ce week-end": {
        en: "This weekend",
        fr: "Ce week-end",
        de: "Dieses Wochenende",
        nl: "Dit weekend",
    }, 
    "Cette semaine": {
        en: "This week",
        fr: "Cette semaine",
        de: "Diese Woche",
        nl: "Deze week",
    },
    "Ce mois-ci": {
        en: "This month",
        fr: "Ce mois-ci",
        de: "Diesen Monat",
        nl: "Deze maand",
    },  
    "Personnalisé (Du ... au ...)": {
        en: "Custom (From ... to ...)",
        fr: "Personnalisé (Du ... au ...)",
        de: "Benutzerdefiniert (Von ... bis ...)",
        nl: "Aangepast (Van ... tot ...)",
    },
    "Personnalisé": {
        en: "Custom",
        fr: "Personnalisé",
        de: "Benutzerdefiniert",
        nl: "Aangepast",
    }
}
